==> drd-8.x-3.9.tar.gz: drd/modules/drd_pi/src/DrdPiDomain.php <==
<?php

namespace Drupal\drd_pi;

use Drupal\drd\Entity\Domain;
use GuzzleHttp\Client;

/**
 * Provides platform based domain.
 */
class DrdPiDomain extends DrdPiEntity {

  protected $domain;
  protected $values;

  /** @var DrdPiCore */
  protected $core;

  /** @var \Drupal\drd\Logging */
  protected $logging;

  public function __construct($label, $type, $account, $id, $core, $domain) {
    parent::__construct($label, $type, $account, $id);
    $this->core = $core;
    $this->domain = $domain;
    $this->logging = \Drupal::service('drd.logging');
  }

  protected function ensureAgent() {
    // Overwrite this in an implementation of the specific PI implementation
    // and make sure the DRD Agent is available and installed.
    return TRUE;
  }

  protected function determineUrl($secure = TRUE) {
    $scheme = $secure ? 'https' : 'http';
    $url = $scheme . '://' . $this->domain;
    $success = FALSE;
    try {
      $client = new Client(['base_uri' => $url]);
      $response = $client->request('head');
      $statusCode = $response->getStatusCode();
      $success = ($statusCode < 300);
    }
    catch (\Exception $ex) {
      // Ignore
    }
    if (!$success) {
      \Drupal::service('drd.logging')->debug('Can not connect to @url', ['@url' => $url]);
      if ($secure) {
        return $this->determineUrl(FALSE);
      }
      return FALSE;
    }
    return $url;
  }

  protected function preSave() {
    /** @var \Drupal\drd\Entity\DomainInterface $domain */
    $domain = $this->getDrdEntity();
    $domain->initValues('');
  }

  protected function postSave() {
    /** @var \Drupal\drd\Entity\DomainInterface $domain */
    $domain = $this->getDrdEntity();
    /** @var \Drupal\drd\Entity\CoreInterface $core */
    $core = $this->core->getDrdEntity();
    if (empty($core->get('drupalroot')->value)) {
      $domain->initCore($core);
    }
    else {
      $domain->remoteInfo();
    }
  }

  /**
   * @inheritDoc
   */
  public function host() {
    return $this->core->host();
  }

  /**
   * @inheritDoc
   */
  public function create() {
    if (!$this->ensureAgent()) {
      $this->logging->log('emergency', 'Unable to ensure DRD Agent remotely');
      return $this;
    }
    if (!$url = $this->determineUrl()) {
      $this->logging->log('emergency', 'Unable to determine remote URL');
      return $this;
    }
    $this->entity = Domain::instanceFromUrl($this->core->getDrdEntity(), $url, [
      'pi_type' => $this->type,
      'pi_account' => $this->account,
      'pi_id_host' => $this->host()->id(),
      'pi_id_core' => $this->core->id(),
      'pi_id_domain' => $this->id,
    ]);
    $this->preSave();
    $this->entity->save();
    $this->postSave();
    return $this;
  }

}

==> drd-8.x-3.10.tar.gz: drd/modules/drd_pi/src/DrdPiDomain.php <==
<?php

namespace Drupal\drd_pi;

use Drupal\drd\Entity\Domain;
use GuzzleHttp\Client;

/**
 * Provides platform based domain.
 */
class DrdPiDomain extends DrdPiEntity {

  /** @var string */
  protected $domain;

  /** @var array */
  protected $values;

  /** @var DrdPiCore */
  protected $core;

  /** @var \Drupal\drd\Logging */
  protected $logging;

  /**
   * @param DrdPiCore $core
   * @param string $domain
   *
   * @return $this
   */
  public function setDetails($core, $domain) {
    $this->core = $core;
    $this->domain = $domain;
    $this->logging = \Drupal::service('drd.logging');
    return $this;
  }

  /**
   * @param bool $secure
   *
   * @return bool|string
   */
  private function determineUrl($secure = TRUE) {
    $scheme = $secure ? 'https' : 'http';
    $url = $scheme . '://' . $this->domain;
    $success = FALSE;
    try {
      $client = new Client(['base_uri' => $url]);
      $response = $client->request('head');
      $statusCode = $response->getStatusCode();
      $success = ($statusCode < 300);
    }
    catch (\Exception $ex) {
      // Ignore
    }
    if (!$success) {
      \Drupal::service('drd.logging')->debug('Can not connect to @url', ['@url' => $url]);
      if ($secure) {
        return $this->determineUrl(FALSE);
      }
      return FALSE;
    }
    return $url;
  }

  /**
   * @inheritDoc
   */
  public function host() {
    return $this->core->host();
  }

  /**
   * @inheritDoc
   */
  public function create() {
    if (!$url = $this->determineUrl()) {
      $this->logging->log('emergency', 'Unable to determine remote URL');
      return $this;
    }

    if (!$this->account->drush($this, 'en drd_agent')) {
      $this->logging->log('emergency', 'Unable to ensure DRD Agent remotely');
      return $this;
    }

    $this->entity = Domain::instanceFromUrl($this->core->getDrdEntity(), $url, [
      'pi_type' => $this->account->getEntityTypeId(),
      'pi_account' => $this->account->id(),
      'pi_id_host' => $this->host()->id(),
      'pi_id_core' => $this->core->id(),
      'pi_id_domain' => $this->id,
    ]);

    /** @var \Drupal\drd\Entity\DomainInterface $domain */
    $domain = $this->getDrdEntity();
    /** @var \Drupal\drd\Entity\CoreInterface $core */
    $core = $this->core->getDrdEntity();

    $domain->initValues('');

    $this->entity->save();

    $this->account->drush($this, 'drd-agent-setup ' . $domain->getRemoteSetupToken(FALSE));

    if (empty($core->get('drupalroot')->value)) {
      $domain->initCore($core);
    }
    else {
      $domain->remoteInfo();
    }

    return $this;
  }

}
